# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HistoricalMessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'created_timestamp': 'int',
        'user_id': 'int',
        'user_type': 'str',
        'channel_type': 'str',
        'org_channel_key': 'str',
        'customer_channel_key': 'str',
        'interaction_id': 'int',
        'external_message_id': 'str',
        'content': 'str',
        'uploads': 'list[UploadModel]',
        'instant_app': 'InstantAppModel',
        'status': 'str',
        'is_whisper': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'created_timestamp': 'createdTimestamp',
        'user_id': 'userId',
        'user_type': 'userType',
        'channel_type': 'channelType',
        'org_channel_key': 'orgChannelKey',
        'customer_channel_key': 'customerChannelKey',
        'interaction_id': 'interactionId',
        'external_message_id': 'externalMessageId',
        'content': 'content',
        'uploads': 'uploads',
        'instant_app': 'instantApp',
        'status': 'status',
        'is_whisper': 'isWhisper'
    }

    def __init__(self, id=None, created_timestamp=None, user_id=None, user_type=None, channel_type=None, org_channel_key=None, customer_channel_key=None, interaction_id=None, external_message_id=None, content=None, uploads=None, instant_app=None, status=None, is_whisper=None):  # noqa: E501
        """HistoricalMessageModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_timestamp = None
        self._user_id = None
        self._user_type = None
        self._channel_type = None
        self._org_channel_key = None
        self._customer_channel_key = None
        self._interaction_id = None
        self._external_message_id = None
        self._content = None
        self._uploads = None
        self._instant_app = None
        self._status = None
        self._is_whisper = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if user_id is not None:
            self.user_id = user_id
        if user_type is not None:
            self.user_type = user_type
        if channel_type is not None:
            self.channel_type = channel_type
        if org_channel_key is not None:
            self.org_channel_key = org_channel_key
        if customer_channel_key is not None:
            self.customer_channel_key = customer_channel_key
        if interaction_id is not None:
            self.interaction_id = interaction_id
        if external_message_id is not None:
            self.external_message_id = external_message_id
        if content is not None:
            self.content = content
        if uploads is not None:
            self.uploads = uploads
        if instant_app is not None:
            self.instant_app = instant_app
        if status is not None:
            self.status = status
        if is_whisper is not None:
            self.is_whisper = is_whisper

    @property
    def id(self):
        """Gets the id of this HistoricalMessageModel.  # noqa: E501


        :return: The id of this HistoricalMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HistoricalMessageModel.


        :param id: The id of this HistoricalMessageModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this HistoricalMessageModel.  # noqa: E501


        :return: The created_timestamp of this HistoricalMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this HistoricalMessageModel.


        :param created_timestamp: The created_timestamp of this HistoricalMessageModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def user_id(self):
        """Gets the user_id of this HistoricalMessageModel.  # noqa: E501


        :return: The user_id of this HistoricalMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this HistoricalMessageModel.


        :param user_id: The user_id of this HistoricalMessageModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def user_type(self):
        """Gets the user_type of this HistoricalMessageModel.  # noqa: E501


        :return: The user_type of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this HistoricalMessageModel.


        :param user_type: The user_type of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEAM_MEMBER", "CUSTOMER", "BOT", "SYSTEM", "TROUBLESHOOTING", "INSTANT_APP"]  # noqa: E501
        if user_type not in allowed_values:
            raise ValueError(
                "Invalid value for `user_type` ({0}), must be one of {1}"  # noqa: E501
                .format(user_type, allowed_values)
            )

        self._user_type = user_type

    @property
    def channel_type(self):
        """Gets the channel_type of this HistoricalMessageModel.  # noqa: E501


        :return: The channel_type of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._channel_type

    @channel_type.setter
    def channel_type(self, channel_type):
        """Sets the channel_type of this HistoricalMessageModel.


        :param channel_type: The channel_type of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SMS", "FACEBOOK", "TWILIO", "LINE", "ZIPWHIP", "SMOOCH_CHAT", "YTEL", "INTERNAL", "BANDWIDTH", "POOL", "MANAGED_BANDWIDTH", "MANAGED_SIGNAL_WIRE", "SIGNAL_WIRE"]  # noqa: E501
        if channel_type not in allowed_values:
            raise ValueError(
                "Invalid value for `channel_type` ({0}), must be one of {1}"  # noqa: E501
                .format(channel_type, allowed_values)
            )

        self._channel_type = channel_type

    @property
    def org_channel_key(self):
        """Gets the org_channel_key of this HistoricalMessageModel.  # noqa: E501


        :return: The org_channel_key of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_key

    @org_channel_key.setter
    def org_channel_key(self, org_channel_key):
        """Sets the org_channel_key of this HistoricalMessageModel.


        :param org_channel_key: The org_channel_key of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """

        self._org_channel_key = org_channel_key

    @property
    def customer_channel_key(self):
        """Gets the customer_channel_key of this HistoricalMessageModel.  # noqa: E501


        :return: The customer_channel_key of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_channel_key

    @customer_channel_key.setter
    def customer_channel_key(self, customer_channel_key):
        """Sets the customer_channel_key of this HistoricalMessageModel.


        :param customer_channel_key: The customer_channel_key of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """

        self._customer_channel_key = customer_channel_key

    @property
    def interaction_id(self):
        """Gets the interaction_id of this HistoricalMessageModel.  # noqa: E501


        :return: The interaction_id of this HistoricalMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._interaction_id

    @interaction_id.setter
    def interaction_id(self, interaction_id):
        """Sets the interaction_id of this HistoricalMessageModel.


        :param interaction_id: The interaction_id of this HistoricalMessageModel.  # noqa: E501
        :type: int
        """

        self._interaction_id = interaction_id

    @property
    def external_message_id(self):
        """Gets the external_message_id of this HistoricalMessageModel.  # noqa: E501


        :return: The external_message_id of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._external_message_id

    @external_message_id.setter
    def external_message_id(self, external_message_id):
        """Sets the external_message_id of this HistoricalMessageModel.


        :param external_message_id: The external_message_id of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """

        self._external_message_id = external_message_id

    @property
    def content(self):
        """Gets the content of this HistoricalMessageModel.  # noqa: E501


        :return: The content of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this HistoricalMessageModel.


        :param content: The content of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def uploads(self):
        """Gets the uploads of this HistoricalMessageModel.  # noqa: E501


        :return: The uploads of this HistoricalMessageModel.  # noqa: E501
        :rtype: list[UploadModel]
        """
        return self._uploads

    @uploads.setter
    def uploads(self, uploads):
        """Sets the uploads of this HistoricalMessageModel.


        :param uploads: The uploads of this HistoricalMessageModel.  # noqa: E501
        :type: list[UploadModel]
        """

        self._uploads = uploads

    @property
    def instant_app(self):
        """Gets the instant_app of this HistoricalMessageModel.  # noqa: E501


        :return: The instant_app of this HistoricalMessageModel.  # noqa: E501
        :rtype: InstantAppModel
        """
        return self._instant_app

    @instant_app.setter
    def instant_app(self, instant_app):
        """Sets the instant_app of this HistoricalMessageModel.


        :param instant_app: The instant_app of this HistoricalMessageModel.  # noqa: E501
        :type: InstantAppModel
        """

        self._instant_app = instant_app

    @property
    def status(self):
        """Gets the status of this HistoricalMessageModel.  # noqa: E501


        :return: The status of this HistoricalMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this HistoricalMessageModel.


        :param status: The status of this HistoricalMessageModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NA", "SENT", "DELIVERED", "READ", "FAILED", "UNDELIVERED", "RECEIVED", "QUEUED", "OPTED_OUT", "ABORTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def is_whisper(self):
        """Gets the is_whisper of this HistoricalMessageModel.  # noqa: E501


        :return: The is_whisper of this HistoricalMessageModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_whisper

    @is_whisper.setter
    def is_whisper(self, is_whisper):
        """Sets the is_whisper of this HistoricalMessageModel.


        :param is_whisper: The is_whisper of this HistoricalMessageModel.  # noqa: E501
        :type: bool
        """

        self._is_whisper = is_whisper

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HistoricalMessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricalMessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsChannelReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'channel_id': 'int',
        'channel_name': 'str',
        'total_messages': 'int',
        'outgoing_messages': 'int',
        'incoming_messages': 'int',
        'total_segments': 'int',
        'outgoing_segments': 'int',
        'incoming_segments': 'int',
        'messages_delivery_failed': 'int',
        'messages_undelivered': 'int',
        'opt_outs': 'int',
        'last_activity_timestamp': 'int',
        'pending_scheduled': 'int'
    }

    attribute_map = {
        'channel_id': 'channelId',
        'channel_name': 'channelName',
        'total_messages': 'totalMessages',
        'outgoing_messages': 'outgoingMessages',
        'incoming_messages': 'incomingMessages',
        'total_segments': 'totalSegments',
        'outgoing_segments': 'outgoingSegments',
        'incoming_segments': 'incomingSegments',
        'messages_delivery_failed': 'messagesDeliveryFailed',
        'messages_undelivered': 'messagesUndelivered',
        'opt_outs': 'optOuts',
        'last_activity_timestamp': 'lastActivityTimestamp',
        'pending_scheduled': 'pendingScheduled'
    }

    def __init__(self, channel_id=None, channel_name=None, total_messages=None, outgoing_messages=None, incoming_messages=None, total_segments=None, outgoing_segments=None, incoming_segments=None, messages_delivery_failed=None, messages_undelivered=None, opt_outs=None, last_activity_timestamp=None, pending_scheduled=None):  # noqa: E501
        """AnalyticsChannelReportModel - a model defined in Swagger"""  # noqa: E501
        self._channel_id = None
        self._channel_name = None
        self._total_messages = None
        self._outgoing_messages = None
        self._incoming_messages = None
        self._total_segments = None
        self._outgoing_segments = None
        self._incoming_segments = None
        self._messages_delivery_failed = None
        self._messages_undelivered = None
        self._opt_outs = None
        self._last_activity_timestamp = None
        self._pending_scheduled = None
        self.discriminator = None
        if channel_id is not None:
            self.channel_id = channel_id
        if channel_name is not None:
            self.channel_name = channel_name
        if total_messages is not None:
            self.total_messages = total_messages
        if outgoing_messages is not None:
            self.outgoing_messages = outgoing_messages
        if incoming_messages is not None:
            self.incoming_messages = incoming_messages
        if total_segments is not None:
            self.total_segments = total_segments
        if outgoing_segments is not None:
            self.outgoing_segments = outgoing_segments
        if incoming_segments is not None:
            self.incoming_segments = incoming_segments
        if messages_delivery_failed is not None:
            self.messages_delivery_failed = messages_delivery_failed
        if messages_undelivered is not None:
            self.messages_undelivered = messages_undelivered
        if opt_outs is not None:
            self.opt_outs = opt_outs
        if last_activity_timestamp is not None:
            self.last_activity_timestamp = last_activity_timestamp
        if pending_scheduled is not None:
            self.pending_scheduled = pending_scheduled

    @property
    def channel_id(self):
        """Gets the channel_id of this AnalyticsChannelReportModel.  # noqa: E501

        The channel's internal id.  # noqa: E501

        :return: The channel_id of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """Sets the channel_id of this AnalyticsChannelReportModel.

        The channel's internal id.  # noqa: E501

        :param channel_id: The channel_id of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._channel_id = channel_id

    @property
    def channel_name(self):
        """Gets the channel_name of this AnalyticsChannelReportModel.  # noqa: E501

        The channel's display name.  # noqa: E501

        :return: The channel_name of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: str
        """
        return self._channel_name

    @channel_name.setter
    def channel_name(self, channel_name):
        """Sets the channel_name of this AnalyticsChannelReportModel.

        The channel's display name.  # noqa: E501

        :param channel_name: The channel_name of this AnalyticsChannelReportModel.  # noqa: E501
        :type: str
        """

        self._channel_name = channel_name

    @property
    def total_messages(self):
        """Gets the total_messages of this AnalyticsChannelReportModel.  # noqa: E501

        The number of messages sent or received by the channel during the window.  # noqa: E501

        :return: The total_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_messages

    @total_messages.setter
    def total_messages(self, total_messages):
        """Sets the total_messages of this AnalyticsChannelReportModel.

        The number of messages sent or received by the channel during the window.  # noqa: E501

        :param total_messages: The total_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._total_messages = total_messages

    @property
    def outgoing_messages(self):
        """Gets the outgoing_messages of this AnalyticsChannelReportModel.  # noqa: E501

        The number of messages sent by the channel during the window.  # noqa: E501

        :return: The outgoing_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages

    @outgoing_messages.setter
    def outgoing_messages(self, outgoing_messages):
        """Sets the outgoing_messages of this AnalyticsChannelReportModel.

        The number of messages sent by the channel during the window.  # noqa: E501

        :param outgoing_messages: The outgoing_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages = outgoing_messages

    @property
    def incoming_messages(self):
        """Gets the incoming_messages of this AnalyticsChannelReportModel.  # noqa: E501

        The number of messages received by the channel during the window.  # noqa: E501

        :return: The incoming_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages

    @incoming_messages.setter
    def incoming_messages(self, incoming_messages):
        """Sets the incoming_messages of this AnalyticsChannelReportModel.

        The number of messages received by the channel during the window.  # noqa: E501

        :param incoming_messages: The incoming_messages of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages = incoming_messages

    @property
    def total_segments(self):
        """Gets the total_segments of this AnalyticsChannelReportModel.  # noqa: E501

        The number of segments sent or received by the channel during the window.  # noqa: E501

        :return: The total_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_segments

    @total_segments.setter
    def total_segments(self, total_segments):
        """Sets the total_segments of this AnalyticsChannelReportModel.

        The number of segments sent or received by the channel during the window.  # noqa: E501

        :param total_segments: The total_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._total_segments = total_segments

    @property
    def outgoing_segments(self):
        """Gets the outgoing_segments of this AnalyticsChannelReportModel.  # noqa: E501

        The number of segments sent by the channel during the window.  # noqa: E501

        :return: The outgoing_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_segments

    @outgoing_segments.setter
    def outgoing_segments(self, outgoing_segments):
        """Sets the outgoing_segments of this AnalyticsChannelReportModel.

        The number of segments sent by the channel during the window.  # noqa: E501

        :param outgoing_segments: The outgoing_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_segments = outgoing_segments

    @property
    def incoming_segments(self):
        """Gets the incoming_segments of this AnalyticsChannelReportModel.  # noqa: E501

        The number of segments received by the channel during the window.  # noqa: E501

        :return: The incoming_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_segments

    @incoming_segments.setter
    def incoming_segments(self, incoming_segments):
        """Sets the incoming_segments of this AnalyticsChannelReportModel.

        The number of segments received by the channel during the window.  # noqa: E501

        :param incoming_segments: The incoming_segments of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._incoming_segments = incoming_segments

    @property
    def messages_delivery_failed(self):
        """Gets the messages_delivery_failed of this AnalyticsChannelReportModel.  # noqa: E501

        The number of messages the failed to send by the channel during the window.  # noqa: E501

        :return: The messages_delivery_failed of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._messages_delivery_failed

    @messages_delivery_failed.setter
    def messages_delivery_failed(self, messages_delivery_failed):
        """Sets the messages_delivery_failed of this AnalyticsChannelReportModel.

        The number of messages the failed to send by the channel during the window.  # noqa: E501

        :param messages_delivery_failed: The messages_delivery_failed of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._messages_delivery_failed = messages_delivery_failed

    @property
    def messages_undelivered(self):
        """Gets the messages_undelivered of this AnalyticsChannelReportModel.  # noqa: E501

        The number of messages that were sent by the channel but were undelivered during the window.  # noqa: E501

        :return: The messages_undelivered of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._messages_undelivered

    @messages_undelivered.setter
    def messages_undelivered(self, messages_undelivered):
        """Sets the messages_undelivered of this AnalyticsChannelReportModel.

        The number of messages that were sent by the channel but were undelivered during the window.  # noqa: E501

        :param messages_undelivered: The messages_undelivered of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._messages_undelivered = messages_undelivered

    @property
    def opt_outs(self):
        """Gets the opt_outs of this AnalyticsChannelReportModel.  # noqa: E501

        The number of opt out messages recevied from customers on the channel during the window.  # noqa: E501

        :return: The opt_outs of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._opt_outs

    @opt_outs.setter
    def opt_outs(self, opt_outs):
        """Sets the opt_outs of this AnalyticsChannelReportModel.

        The number of opt out messages recevied from customers on the channel during the window.  # noqa: E501

        :param opt_outs: The opt_outs of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._opt_outs = opt_outs

    @property
    def last_activity_timestamp(self):
        """Gets the last_activity_timestamp of this AnalyticsChannelReportModel.  # noqa: E501

        The time the last message was sent or received by the channel.  # noqa: E501

        :return: The last_activity_timestamp of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._last_activity_timestamp

    @last_activity_timestamp.setter
    def last_activity_timestamp(self, last_activity_timestamp):
        """Sets the last_activity_timestamp of this AnalyticsChannelReportModel.

        The time the last message was sent or received by the channel.  # noqa: E501

        :param last_activity_timestamp: The last_activity_timestamp of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._last_activity_timestamp = last_activity_timestamp

    @property
    def pending_scheduled(self):
        """Gets the pending_scheduled of this AnalyticsChannelReportModel.  # noqa: E501

        The number of scheduled actions currently waiting to be sent on the channel, regardless of the time window selected.  # noqa: E501

        :return: The pending_scheduled of this AnalyticsChannelReportModel.  # noqa: E501
        :rtype: int
        """
        return self._pending_scheduled

    @pending_scheduled.setter
    def pending_scheduled(self, pending_scheduled):
        """Sets the pending_scheduled of this AnalyticsChannelReportModel.

        The number of scheduled actions currently waiting to be sent on the channel, regardless of the time window selected.  # noqa: E501

        :param pending_scheduled: The pending_scheduled of this AnalyticsChannelReportModel.  # noqa: E501
        :type: int
        """

        self._pending_scheduled = pending_scheduled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsChannelReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsChannelReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class UploadsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_upload(self, upload_id, **kwargs):  # noqa: E501
        """Deletes an Upload  # noqa: E501

        _in snippets: platform.api.uploads.deleteUpload_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_upload(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int upload_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_upload_with_http_info(upload_id, **kwargs)  # noqa: E501
            return data

    def delete_upload_with_http_info(self, upload_id, **kwargs):  # noqa: E501
        """Deletes an Upload  # noqa: E501

        _in snippets: platform.api.uploads.deleteUpload_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_upload_with_http_info(upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int upload_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_upload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in params or
                params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `delete_upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'upload_id' in params:
            path_params['uploadId'] = params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/uploads/{uploadId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_upload_by_key(self, key, **kwargs):  # noqa: E501
        """Deletes an Upload  # noqa: E501

        _in snippets: platform.api.uploads.deleteUploadByKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_upload_by_key(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_upload_by_key_with_http_info(key, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_upload_by_key_with_http_info(key, **kwargs)  # noqa: E501
            return data

    def delete_upload_by_key_with_http_info(self, key, **kwargs):  # noqa: E501
        """Deletes an Upload  # noqa: E501

        _in snippets: platform.api.uploads.deleteUploadByKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_upload_by_key_with_http_info(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_upload_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `delete_upload_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/uploads/key/{key}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_file(self, file, **kwargs):  # noqa: E501
        """Upload a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file: (required)
        :return: UploadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_file_with_http_info(file, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_file_with_http_info(file, **kwargs)  # noqa: E501
            return data

    def upload_file_with_http_info(self, file, **kwargs):  # noqa: E501
        """Upload a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_with_http_info(file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file: (required)
        :return: UploadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file' is set
        if ('file' not in params or
                params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `upload_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.messages_api import MessagesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMessagesApi(unittest.TestCase):
    """MessagesApi unit test stubs"""

    def setUp(self):
        self.api = MessagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_message(self):
        """Test case for get_message

        Gets a single specific message by its internal id  # noqa: E501
        """
        pass

    def test_get_message_by_external_id(self):
        """Test case for get_message_by_external_id

        Gets a single specific message by its external id  # noqa: E501
        """
        pass

    def test_get_message_history(self):
        """Test case for get_message_history

        Gets historial messages in bulk  # noqa: E501
        """
        pass

    def test_send_file_to_customer(self):
        """Test case for send_file_to_customer

        Sends a file and an optional message to a customer, creating the customer, customer channel and conversation if needed.  # noqa: E501
        """
        pass

    def test_send_to_customer(self):
        """Test case for send_to_customer

        Sends a message and an optional instant app to a customer using API Ids, creating the customer, customer channel and conversation if needed.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.tags_api import TagsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tag(self):
        """Test case for add_tag

        Creates a tag  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Deletes the tag  # noqa: E501
        """
        pass

    def test_get_customer_tags1(self):
        """Test case for get_customer_tags1

        Gets the customers for a specific tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Gets all tags  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.groups_api import GroupsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_group(self):
        """Test case for add_group

        Creates a group  # noqa: E501
        """
        pass

    def test_delete_group(self):
        """Test case for delete_group

        Deletes a group  # noqa: E501
        """
        pass

    def test_get_group(self):
        """Test case for get_group

        Gets the details of a specific group  # noqa: E501
        """
        pass

    def test_get_groups(self):
        """Test case for get_groups

        Gets all the groups in the org  # noqa: E501
        """
        pass

    def test_get_org_channel_permission(self):
        """Test case for get_org_channel_permission

        Gets a group's's orgChannel permission  # noqa: E501
        """
        pass

    def test_get_org_channel_permissions(self):
        """Test case for get_org_channel_permissions

        Gets a group's's orgChannel permissions  # noqa: E501
        """
        pass

    def test_get_permission(self):
        """Test case for get_permission

        Gets a group's permission  # noqa: E501
        """
        pass

    def test_get_permissions(self):
        """Test case for get_permissions

        Gets a group's permissions  # noqa: E501
        """
        pass

    def test_set_org_channel_permissions(self):
        """Test case for set_org_channel_permissions

        Sets a group's orgChannel permissions  # noqa: E501
        """
        pass

    def test_set_permissions(self):
        """Test case for set_permissions

        Sets a group's permissions  # noqa: E501
        """
        pass

    def test_update_group(self):
        """Test case for update_group

        Modifies a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ContactListAddContactsModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'identity_type': 'str',
        'contacts': 'list[Contact]'
    }

    attribute_map = {
        'identity_type': 'identityType',
        'contacts': 'contacts'
    }

    def __init__(self, identity_type=None, contacts=None):  # noqa: E501
        """ContactListAddContactsModel - a model defined in Swagger"""  # noqa: E501
        self._identity_type = None
        self._contacts = None
        self.discriminator = None
        if identity_type is not None:
            self.identity_type = identity_type
        if contacts is not None:
            self.contacts = contacts

    @property
    def identity_type(self):
        """Gets the identity_type of this ContactListAddContactsModel.  # noqa: E501

        Identity type for the customer channel  # noqa: E501

        :return: The identity_type of this ContactListAddContactsModel.  # noqa: E501
        :rtype: str
        """
        return self._identity_type

    @identity_type.setter
    def identity_type(self, identity_type):
        """Sets the identity_type of this ContactListAddContactsModel.

        Identity type for the customer channel  # noqa: E501

        :param identity_type: The identity_type of this ContactListAddContactsModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SMS", "FB", "CUSTOMER_EXTERNAL", "LIVE_CHAT", "LINE"]  # noqa: E501
        if identity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `identity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(identity_type, allowed_values)
            )

        self._identity_type = identity_type

    @property
    def contacts(self):
        """Gets the contacts of this ContactListAddContactsModel.  # noqa: E501

        The list of contacts to add. You may specify up to 500 contacts. The total number of contacts in the Contact List may not exceed 20,000  # noqa: E501

        :return: The contacts of this ContactListAddContactsModel.  # noqa: E501
        :rtype: list[Contact]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this ContactListAddContactsModel.

        The list of contacts to add. You may specify up to 500 contacts. The total number of contacts in the Contact List may not exceed 20,000  # noqa: E501

        :param contacts: The contacts of this ContactListAddContactsModel.  # noqa: E501
        :type: list[Contact]
        """

        self._contacts = contacts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContactListAddContactsModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactListAddContactsModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SendToCustomerMessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'instant_app_parameters': 'dict(str, str)',
        'instant_app_schema_api_id': 'str',
        'org_channel_api_id': 'str',
        'customer_channel_key': 'str',
        'customer_channel_id': 'int',
        'ignore_delivery_restrictions': 'bool'
    }

    attribute_map = {
        'message': 'message',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_schema_api_id': 'instantAppSchemaApiId',
        'org_channel_api_id': 'orgChannelApiId',
        'customer_channel_key': 'customerChannelKey',
        'customer_channel_id': 'customerChannelId',
        'ignore_delivery_restrictions': 'ignoreDeliveryRestrictions'
    }

    def __init__(self, message=None, instant_app_parameters=None, instant_app_schema_api_id=None, org_channel_api_id=None, customer_channel_key=None, customer_channel_id=None, ignore_delivery_restrictions=None):  # noqa: E501
        """SendToCustomerMessageModel - a model defined in Swagger"""  # noqa: E501
        self._message = None
        self._instant_app_parameters = None
        self._instant_app_schema_api_id = None
        self._org_channel_api_id = None
        self._customer_channel_key = None
        self._customer_channel_id = None
        self._ignore_delivery_restrictions = None
        self.discriminator = None
        self.message = message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_schema_api_id is not None:
            self.instant_app_schema_api_id = instant_app_schema_api_id
        self.org_channel_api_id = org_channel_api_id
        if customer_channel_key is not None:
            self.customer_channel_key = customer_channel_key
        if customer_channel_id is not None:
            self.customer_channel_id = customer_channel_id
        if ignore_delivery_restrictions is not None:
            self.ignore_delivery_restrictions = ignore_delivery_restrictions

    @property
    def message(self):
        """Gets the message of this SendToCustomerMessageModel.  # noqa: E501

        The message to send to the user.  If you specify an instant app schema apiId, {link} will be replaced with the instant app customer url link.  # noqa: E501

        :return: The message of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this SendToCustomerMessageModel.

        The message to send to the user.  If you specify an instant app schema apiId, {link} will be replaced with the instant app customer url link.  # noqa: E501

        :param message: The message of this SendToCustomerMessageModel.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this SendToCustomerMessageModel.  # noqa: E501

        Optional Instant App parameters passed into the instant app  # noqa: E501

        :return: The instant_app_parameters of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this SendToCustomerMessageModel.

        Optional Instant App parameters passed into the instant app  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this SendToCustomerMessageModel.  # noqa: E501
        :type: dict(str, str)
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_schema_api_id(self):
        """Gets the instant_app_schema_api_id of this SendToCustomerMessageModel.  # noqa: E501

        Optional schema apiId (or internal id) used to create an instance of an instant app.  If provided, an instant app an instant app instance will be created and the customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_schema_api_id of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_api_id

    @instant_app_schema_api_id.setter
    def instant_app_schema_api_id(self, instant_app_schema_api_id):
        """Sets the instant_app_schema_api_id of this SendToCustomerMessageModel.

        Optional schema apiId (or internal id) used to create an instance of an instant app.  If provided, an instant app an instant app instance will be created and the customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_schema_api_id: The instant_app_schema_api_id of this SendToCustomerMessageModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_api_id = instant_app_schema_api_id

    @property
    def org_channel_api_id(self):
        """Gets the org_channel_api_id of this SendToCustomerMessageModel.  # noqa: E501

        The org channel apiId (or internal id) of the sending channel  # noqa: E501

        :return: The org_channel_api_id of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_api_id

    @org_channel_api_id.setter
    def org_channel_api_id(self, org_channel_api_id):
        """Sets the org_channel_api_id of this SendToCustomerMessageModel.

        The org channel apiId (or internal id) of the sending channel  # noqa: E501

        :param org_channel_api_id: The org_channel_api_id of this SendToCustomerMessageModel.  # noqa: E501
        :type: str
        """
        if org_channel_api_id is None:
            raise ValueError("Invalid value for `org_channel_api_id`, must not be `None`")  # noqa: E501

        self._org_channel_api_id = org_channel_api_id

    @property
    def customer_channel_key(self):
        """Gets the customer_channel_key of this SendToCustomerMessageModel.  # noqa: E501

        The key of the customer channel, for instance, the customer phone number to SMS to.  Must supply this or customerChannelId  # noqa: E501

        :return: The customer_channel_key of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_channel_key

    @customer_channel_key.setter
    def customer_channel_key(self, customer_channel_key):
        """Sets the customer_channel_key of this SendToCustomerMessageModel.

        The key of the customer channel, for instance, the customer phone number to SMS to.  Must supply this or customerChannelId  # noqa: E501

        :param customer_channel_key: The customer_channel_key of this SendToCustomerMessageModel.  # noqa: E501
        :type: str
        """

        self._customer_channel_key = customer_channel_key

    @property
    def customer_channel_id(self):
        """Gets the customer_channel_id of this SendToCustomerMessageModel.  # noqa: E501

        The internal id of the customer channel key. Must supply this or the customerChannelKey  # noqa: E501

        :return: The customer_channel_id of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._customer_channel_id

    @customer_channel_id.setter
    def customer_channel_id(self, customer_channel_id):
        """Sets the customer_channel_id of this SendToCustomerMessageModel.

        The internal id of the customer channel key. Must supply this or the customerChannelKey  # noqa: E501

        :param customer_channel_id: The customer_channel_id of this SendToCustomerMessageModel.  # noqa: E501
        :type: int
        """

        self._customer_channel_id = customer_channel_id

    @property
    def ignore_delivery_restrictions(self):
        """Gets the ignore_delivery_restrictions of this SendToCustomerMessageModel.  # noqa: E501

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :return: The ignore_delivery_restrictions of this SendToCustomerMessageModel.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_delivery_restrictions

    @ignore_delivery_restrictions.setter
    def ignore_delivery_restrictions(self, ignore_delivery_restrictions):
        """Sets the ignore_delivery_restrictions of this SendToCustomerMessageModel.

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :param ignore_delivery_restrictions: The ignore_delivery_restrictions of this SendToCustomerMessageModel.  # noqa: E501
        :type: bool
        """

        self._ignore_delivery_restrictions = ignore_delivery_restrictions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SendToCustomerMessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendToCustomerMessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.maps_api import MapsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMapsApi(unittest.TestCase):
    """MapsApi unit test stubs"""

    def setUp(self):
        self.api = MapsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_customer_to_map(self):
        """Test case for add_customer_to_map

        Adds a customer location to a map  # noqa: E501
        """
        pass

    def test_add_google_map(self):
        """Test case for add_google_map

        Creates a map  # noqa: E501
        """
        pass

    def test_delete_google_map(self):
        """Test case for delete_google_map

        Deletes a map  # noqa: E501
        """
        pass

    def test_get_google_map(self):
        """Test case for get_google_map

        Gets a map  # noqa: E501
        """
        pass

    def test_remove_customer_from_map(self):
        """Test case for remove_customer_from_map

        Removes a customer location from a map  # noqa: E501
        """
        pass

    def test_update_google_map(self):
        """Test case for update_google_map

        Update a map  # noqa: E501
        """
        pass

    def test_update_google_map_icons(self):
        """Test case for update_google_map_icons

        Update a map's icons  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApiKeyModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'token': 'str',
        'active': 'bool',
        'creator_id': 'int',
        'created_timestamp': 'int',
        'token_generator_id': 'int',
        'token_generated_timestamp': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'token': 'token',
        'active': 'active',
        'creator_id': 'creatorId',
        'created_timestamp': 'createdTimestamp',
        'token_generator_id': 'tokenGeneratorId',
        'token_generated_timestamp': 'tokenGeneratedTimestamp'
    }

    def __init__(self, id=None, name=None, token=None, active=None, creator_id=None, created_timestamp=None, token_generator_id=None, token_generated_timestamp=None):  # noqa: E501
        """ApiKeyModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._token = None
        self._active = None
        self._creator_id = None
        self._created_timestamp = None
        self._token_generator_id = None
        self._token_generated_timestamp = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if token is not None:
            self.token = token
        if active is not None:
            self.active = active
        if creator_id is not None:
            self.creator_id = creator_id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if token_generator_id is not None:
            self.token_generator_id = token_generator_id
        if token_generated_timestamp is not None:
            self.token_generated_timestamp = token_generated_timestamp

    @property
    def id(self):
        """Gets the id of this ApiKeyModel.  # noqa: E501

        The system generated unique id for this API Key.  # noqa: E501

        :return: The id of this ApiKeyModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApiKeyModel.

        The system generated unique id for this API Key.  # noqa: E501

        :param id: The id of this ApiKeyModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ApiKeyModel.  # noqa: E501

        A descriptive name for this API Key to show in agent UIs.  # noqa: E501

        :return: The name of this ApiKeyModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApiKeyModel.

        A descriptive name for this API Key to show in agent UIs.  # noqa: E501

        :param name: The name of this ApiKeyModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def token(self):
        """Gets the token of this ApiKeyModel.  # noqa: E501

        Requests made to the API must include this API Key Token as an HTTP header named PLACEHOLDER within the request in order to prove the request is authorized  # noqa: E501

        :return: The token of this ApiKeyModel.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this ApiKeyModel.

        Requests made to the API must include this API Key Token as an HTTP header named PLACEHOLDER within the request in order to prove the request is authorized  # noqa: E501

        :param token: The token of this ApiKeyModel.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def active(self):
        """Gets the active of this ApiKeyModel.  # noqa: E501

        Whether the API Key is active.  # noqa: E501

        :return: The active of this ApiKeyModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ApiKeyModel.

        Whether the API Key is active.  # noqa: E501

        :param active: The active of this ApiKeyModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def creator_id(self):
        """Gets the creator_id of this ApiKeyModel.  # noqa: E501

        ID of the user that created the API Key.  # noqa: E501

        :return: The creator_id of this ApiKeyModel.  # noqa: E501
        :rtype: int
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this ApiKeyModel.

        ID of the user that created the API Key.  # noqa: E501

        :param creator_id: The creator_id of this ApiKeyModel.  # noqa: E501
        :type: int
        """

        self._creator_id = creator_id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this ApiKeyModel.  # noqa: E501

        The time the API Key was created.  # noqa: E501

        :return: The created_timestamp of this ApiKeyModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this ApiKeyModel.

        The time the API Key was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this ApiKeyModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def token_generator_id(self):
        """Gets the token_generator_id of this ApiKeyModel.  # noqa: E501

        ID of the user that generated the token.  # noqa: E501

        :return: The token_generator_id of this ApiKeyModel.  # noqa: E501
        :rtype: int
        """
        return self._token_generator_id

    @token_generator_id.setter
    def token_generator_id(self, token_generator_id):
        """Sets the token_generator_id of this ApiKeyModel.

        ID of the user that generated the token.  # noqa: E501

        :param token_generator_id: The token_generator_id of this ApiKeyModel.  # noqa: E501
        :type: int
        """

        self._token_generator_id = token_generator_id

    @property
    def token_generated_timestamp(self):
        """Gets the token_generated_timestamp of this ApiKeyModel.  # noqa: E501

        The time the token was generated.  # noqa: E501

        :return: The token_generated_timestamp of this ApiKeyModel.  # noqa: E501
        :rtype: int
        """
        return self._token_generated_timestamp

    @token_generated_timestamp.setter
    def token_generated_timestamp(self, token_generated_timestamp):
        """Sets the token_generated_timestamp of this ApiKeyModel.

        The time the token was generated.  # noqa: E501

        :param token_generated_timestamp: The token_generated_timestamp of this ApiKeyModel.  # noqa: E501
        :type: int
        """

        self._token_generated_timestamp = token_generated_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiKeyModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiKeyModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PostMessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team_member_id': 'int',
        'content': 'str',
        'ignore_delivery_restrictions': 'bool'
    }

    attribute_map = {
        'team_member_id': 'teamMemberId',
        'content': 'content',
        'ignore_delivery_restrictions': 'ignoreDeliveryRestrictions'
    }

    def __init__(self, team_member_id=None, content=None, ignore_delivery_restrictions=None):  # noqa: E501
        """PostMessageModel - a model defined in Swagger"""  # noqa: E501
        self._team_member_id = None
        self._content = None
        self._ignore_delivery_restrictions = None
        self.discriminator = None
        self.team_member_id = team_member_id
        self.content = content
        if ignore_delivery_restrictions is not None:
            self.ignore_delivery_restrictions = ignore_delivery_restrictions

    @property
    def team_member_id(self):
        """Gets the team_member_id of this PostMessageModel.  # noqa: E501

        ID of the team member.  # noqa: E501

        :return: The team_member_id of this PostMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._team_member_id

    @team_member_id.setter
    def team_member_id(self, team_member_id):
        """Sets the team_member_id of this PostMessageModel.

        ID of the team member.  # noqa: E501

        :param team_member_id: The team_member_id of this PostMessageModel.  # noqa: E501
        :type: int
        """
        if team_member_id is None:
            raise ValueError("Invalid value for `team_member_id`, must not be `None`")  # noqa: E501

        self._team_member_id = team_member_id

    @property
    def content(self):
        """Gets the content of this PostMessageModel.  # noqa: E501

        The content of the message  # noqa: E501

        :return: The content of this PostMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PostMessageModel.

        The content of the message  # noqa: E501

        :param content: The content of this PostMessageModel.  # noqa: E501
        :type: str
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def ignore_delivery_restrictions(self):
        """Gets the ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :return: The ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_delivery_restrictions

    @ignore_delivery_restrictions.setter
    def ignore_delivery_restrictions(self, ignore_delivery_restrictions):
        """Sets the ignore_delivery_restrictions of this PostMessageModel.

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :param ignore_delivery_restrictions: The ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501
        :type: bool
        """

        self._ignore_delivery_restrictions = ignore_delivery_restrictions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PostMessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostMessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class InstantAppsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_audit_message(self, instant_app_id, **kwargs):  # noqa: E501
        """Add a new audit message  # noqa: E501

        _in snippets: platform.api.instantApps.addAuditMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_audit_message(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param AuditMessageModel body:
        :return: AuditMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_audit_message_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_audit_message_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def add_audit_message_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Add a new audit message  # noqa: E501

        _in snippets: platform.api.instantApps.addAuditMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_audit_message_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param AuditMessageModel body:
        :return: AuditMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_audit_message" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `add_audit_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/audit_messages', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuditMessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancel_timers(self, instant_app_id, **kwargs):  # noqa: E501
        """Cancels any outstanding timers matching the params  # noqa: E501

        _in snippets: platform.api.instantApps.cancelTimers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_timers(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppTimersModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_timers_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_timers_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def cancel_timers_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Cancels any outstanding timers matching the params  # noqa: E501

        _in snippets: platform.api.instantApps.cancelTimers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_timers_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppTimersModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_timers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `cancel_timers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/timers/cancel', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_messages(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the audit trail messages of an Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getAuditMessages_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_messages(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param int first:
        :param int max:
        :param bool desc:
        :return: AuditMessageModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_messages_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_messages_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def get_audit_messages_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the audit trail messages of an Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getAuditMessages_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_messages_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param int first:
        :param int max:
        :param bool desc:
        :return: AuditMessageModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'first', 'max', 'desc']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_messages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `get_audit_messages`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501
        if 'desc' in params:
            query_params.append(('desc', params['desc']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/audit_messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuditMessageModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data1(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the value for every element of the Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data1(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: InstantAppDataModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data1_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data1_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def get_data1_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the value for every element of the Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data1_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: InstantAppDataModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `get_data1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/elements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppDataModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_instant_app(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the details of a specific Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getInstantApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: InstantAppModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_instant_app_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_instant_app_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def get_instant_app_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the details of a specific Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.getInstantApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: InstantAppModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instant_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `get_instant_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def is_instant_app_locked(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the lock status of an Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.isInstantAppLocked_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.is_instant_app_locked(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.is_instant_app_locked_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.is_instant_app_locked_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def is_instant_app_locked_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Gets the lock status of an Instant App  # noqa: E501

        _in snippets: platform.api.instantApps.isInstantAppLocked_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.is_instant_app_locked_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method is_instant_app_locked" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `is_instant_app_locked`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/locked', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_data(self, instant_app_id, **kwargs):  # noqa: E501
        """Updates the value for every element of the Instant App given  # noqa: E501

        _in snippets: platform.api.instantApps.saveData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_data(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppDataModel body:
        :return: InstantAppDataModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_data_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.save_data_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def save_data_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Updates the value for every element of the Instant App given  # noqa: E501

        _in snippets: platform.api.instantApps.saveData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_data_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppDataModel body:
        :return: InstantAppDataModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `save_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/elements', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppDataModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_icon(self, instant_app_id, **kwargs):  # noqa: E501
        """Updates the icon and icon label for an instant app  # noqa: E501

        _in snippets: platform.api.instantApps.setIcon_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_icon(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppIconModel body:
        :return: InstantAppIconModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_icon_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_icon_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def set_icon_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Updates the icon and icon label for an instant app  # noqa: E501

        _in snippets: platform.api.instantApps.setIcon_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_icon_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param InstantAppIconModel body:
        :return: InstantAppIconModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_icon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `set_icon`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/icon', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InstantAppIconModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_instant_app_locked(self, instant_app_id, **kwargs):  # noqa: E501
        """Set whether an Instant App is locked  # noqa: E501

        _in snippets: platform.api.instantApps.setInstantAppLocked_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_instant_app_locked(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param bool body:
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_instant_app_locked_with_http_info(instant_app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_instant_app_locked_with_http_info(instant_app_id, **kwargs)  # noqa: E501
            return data

    def set_instant_app_locked_with_http_info(self, instant_app_id, **kwargs):  # noqa: E501
        """Set whether an Instant App is locked  # noqa: E501

        _in snippets: platform.api.instantApps.setInstantAppLocked_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_instant_app_locked_with_http_info(instant_app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int instant_app_id: (required)
        :param bool body:
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['instant_app_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_instant_app_locked" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'instant_app_id' is set
        if ('instant_app_id' not in params or
                params['instant_app_id'] is None):
            raise ValueError("Missing the required parameter `instant_app_id` when calling `set_instant_app_locked`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instant_app_id' in params:
            path_params['instantAppId'] = params['instant_app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/instant_apps/{instantAppId}/locked', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pools_api import PoolsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPoolsApi(unittest.TestCase):
    """PoolsApi unit test stubs"""

    def setUp(self):
        self.api = PoolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_pool(self):
        """Test case for add_pool

        Creates a pool  # noqa: E501
        """
        pass

    def test_delete_pool(self):
        """Test case for delete_pool

        Deletes a pool  # noqa: E501
        """
        pass

    def test_get_available_numbers(self):
        """Test case for get_available_numbers

        Gets phone numbers that are available to be purchased from the given provider  # noqa: E501
        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        Gets a specific pool  # noqa: E501
        """
        pass

    def test_get_pools(self):
        """Test case for get_pools

        Gets all pools  # noqa: E501
        """
        pass

    def test_update_pool(self):
        """Test case for update_pool

        Updates a pool  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.scheduled_actions_api import ScheduledActionsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestScheduledActionsApi(unittest.TestCase):
    """ScheduledActionsApi unit test stubs"""

    def setUp(self):
        self.api = ScheduledActionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_scheduled_action(self):
        """Test case for abort_scheduled_action

        Abort a Scheduled Action  # noqa: E501
        """
        pass

    def test_add_scheduled_action(self):
        """Test case for add_scheduled_action

        Creates a Scheduled Action  # noqa: E501
        """
        pass

    def test_get_pending_scheduled_actions(self):
        """Test case for get_pending_scheduled_actions

        Gets pending Scheduled Actions  # noqa: E501
        """
        pass

    def test_get_scheduled_action(self):
        """Test case for get_scheduled_action

        Gets a specific Scheduled Action  # noqa: E501
        """
        pass

    def test_get_scheduled_actions(self):
        """Test case for get_scheduled_actions

        Gets all Scheduled Actions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgChannelWithPermissionsModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_channel': 'OrgChannelModel',
        'permissions': 'list[str]'
    }

    attribute_map = {
        'org_channel': 'orgChannel',
        'permissions': 'permissions'
    }

    def __init__(self, org_channel=None, permissions=None):  # noqa: E501
        """OrgChannelWithPermissionsModel - a model defined in Swagger"""  # noqa: E501
        self._org_channel = None
        self._permissions = None
        self.discriminator = None
        if org_channel is not None:
            self.org_channel = org_channel
        if permissions is not None:
            self.permissions = permissions

    @property
    def org_channel(self):
        """Gets the org_channel of this OrgChannelWithPermissionsModel.  # noqa: E501


        :return: The org_channel of this OrgChannelWithPermissionsModel.  # noqa: E501
        :rtype: OrgChannelModel
        """
        return self._org_channel

    @org_channel.setter
    def org_channel(self, org_channel):
        """Sets the org_channel of this OrgChannelWithPermissionsModel.


        :param org_channel: The org_channel of this OrgChannelWithPermissionsModel.  # noqa: E501
        :type: OrgChannelModel
        """

        self._org_channel = org_channel

    @property
    def permissions(self):
        """Gets the permissions of this OrgChannelWithPermissionsModel.  # noqa: E501

        The permissions for the org channel.  # noqa: E501

        :return: The permissions of this OrgChannelWithPermissionsModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this OrgChannelWithPermissionsModel.

        The permissions for the org channel.  # noqa: E501

        :param permissions: The permissions of this OrgChannelWithPermissionsModel.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["CAN_VIEW", "CAN_SEND"]  # noqa: E501
        if not set(permissions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `permissions` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(permissions) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgChannelWithPermissionsModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgChannelWithPermissionsModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.contact_lists_api import ContactListsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestContactListsApi(unittest.TestCase):
    """ContactListsApi unit test stubs"""

    def setUp(self):
        self.api = ContactListsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contact_list(self):
        """Test case for add_contact_list

        Creates a Contact List  # noqa: E501
        """
        pass

    def test_delete_contact_list(self):
        """Test case for delete_contact_list

        Deletes a Contact List  # noqa: E501
        """
        pass

    def test_get_contact_list(self):
        """Test case for get_contact_list

        Gets a specific Contact List  # noqa: E501
        """
        pass

    def test_get_contact_lists(self):
        """Test case for get_contact_lists

        Gets all Contact Lists  # noqa: E501
        """
        pass

    def test_perform_action1(self):
        """Test case for perform_action1

        Performs an action on the contacts in a Contact List  # noqa: E501
        """
        pass

    def test_update_contact_list(self):
        """Test case for update_contact_list

        Modifies a Contact List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
